==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: cn/sh1rocu/touhoulittlemaid/util/forge/CommonHooks.java <==
package cn.sh1rocu.touhoulittlemaid.util.forge;

import java.util.Optional;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2680;
import net.minecraft.class_3481;
import net.minecraft.class_3532;
import net.minecraft.class_4538;

/**
 * From NeoForge
 */
public class CommonHooks {
    public static Optional<class_2338> isLivingOnLadder(class_2680 state, class_1937 level, class_2338 pos, class_1309 entity) {
        boolean isSpectator = (entity instanceof class_1657 && entity.method_7325());
        if (isSpectator)
            return Optional.empty();
/*        if (!NeoForgeConfig.SERVER.fullBoundingBoxLadders.get()) {
            return state.isLadder(level, pos, entity) ? Optional.of(pos) : Optional.empty();
        } else
        {*/
        class_238 bb = entity.method_5829();
        int mX = class_3532.method_15357(bb.field_1323);
        int mY = class_3532.method_15357(bb.field_1322);
        int mZ = class_3532.method_15357(bb.field_1321);
        for (int y2 = mY; y2 < bb.field_1325; y2++) {
            for (int x2 = mX; x2 < bb.field_1320; x2++) {
                for (int z2 = mZ; z2 < bb.field_1324; z2++) {
                    class_2338 tmp = new class_2338(x2, y2, z2);
                    state = level.method_8320(tmp);
                    /*if (state.isLadder(level, tmp, entity)) {*/
                    if (isLadder(state, level, tmp, entity))
                        return Optional.of(tmp);
                }
            }
        }
        //}
        return Optional.empty();
    }
    //}

    public static boolean isLadder(class_2680 state, class_4538 level, class_2338 pos, class_1309 entity) {
        return state.method_26164(class_3481.field_22414);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.0.5-neo1.3.6-sources.jar: cn/sh1rocu/touhoulittlemaid/util/forge/CommonHooks.java <==
package cn.sh1rocu.touhoulittlemaid.util.forge;

import cn.sh1rocu.touhoulittlemaid.api.event.FarmlandTrampleEvent;
import java.util.Optional;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2680;
import net.minecraft.class_3481;
import net.minecraft.class_3532;
import net.minecraft.class_4538;

/**
 * From NeoForge
 */
public class CommonHooks {
    public static Optional<class_2338> isLivingOnLadder(class_2680 state, class_1937 level, class_2338 pos, class_1309 entity) {
        boolean isSpectator = (entity instanceof class_1657 && entity.method_7325());
        if (isSpectator)
            return Optional.empty();
/*        if (!NeoForgeConfig.SERVER.fullBoundingBoxLadders.get()) {
            return state.isLadder(level, pos, entity) ? Optional.of(pos) : Optional.empty();
        } else
        {*/
        class_238 bb = entity.method_5829();
        int mX = class_3532.method_15357(bb.field_1323);
        int mY = class_3532.method_15357(bb.field_1322);
        int mZ = class_3532.method_15357(bb.field_1321);
        for (int y2 = mY; y2 < bb.field_1325; y2++) {
            for (int x2 = mX; x2 < bb.field_1320; x2++) {
                for (int z2 = mZ; z2 < bb.field_1324; z2++) {
                    class_2338 tmp = new class_2338(x2, y2, z2);
                    state = level.method_8320(tmp);
                    /*if (state.isLadder(level, tmp, entity)) {*/
                    if (isLadder(state, level, tmp, entity))
                        return Optional.of(tmp);
                }
            }
        }
        //}
        return Optional.empty();
    }
    //}

    public static boolean isLadder(class_2680 state, class_4538 level, class_2338 pos, class_1309 entity) {
        return state.method_26164(class_3481.field_22414);
    }

    public static boolean onFarmlandTrample(class_1937 level, class_2338 pos, class_2680 state, float fallDistance, class_1297 entity) {
        FarmlandTrampleEvent event = new FarmlandTrampleEvent(level, pos, state, fallDistance, entity);
        FarmlandTrampleEvent.CALLBACK.invoker().post(event);
        return !event.isCanceled();
    }
}
